pub struct DropEffects(/* private fields */);Expand description
A compact set of drop effects a target supports.
Implementations
Sourceimpl DropEffects
impl DropEffects
pub const EMPTY: Self
pub const MOVE: Self
pub const COPY: Self
pub const LINK: Self
pub const STANDARD: Self
pub const ALL: Self = Self::STANDARD
pub fn contains(self, effect: DropEffect) -> bool
pub fn is_empty(self) -> bool
Sourcepub fn negotiate(self, proposed: DropEffect) -> Option<DropEffect>
pub fn negotiate(self, proposed: DropEffect) -> Option<DropEffect>
Accept the proposed effect or choose a deterministic supported
fallback. None is never chosen as a fallback for an active drop.