#[non_exhaustive]pub struct DragStart<T> {
pub payload: T,
pub source: Option<ZoneId>,
pub pointer: Point,
pub grab: Point,
pub effect: DropEffect,
pub mode: DragMode,
pub pointer_kind: PointerKind,
pub source_rect: Option<Rect>,
}Expand description
Complete input for starting a drag with an explicit stable identity.
Construct this with DragStart::new and use the builder methods for
optional metadata. The struct is non-exhaustive so future drag metadata
can be added without breaking downstream callers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.payload: Tsource: Option<ZoneId>pointer: Pointgrab: Pointeffect: DropEffectmode: DragModepointer_kind: PointerKindsource_rect: Option<Rect>Implementations
Sourceimpl<T> DragStart<T>
impl<T> DragStart<T>
Sourcepub fn new(payload: T, pointer: Point) -> Self
pub fn new(payload: T, pointer: Point) -> Self
Create a pointer drag at pointer with default grab and move effect.
pub fn with_source(self, source: Option<ZoneId>) -> Self
pub fn with_grab(self, grab: Point) -> Self
pub fn with_effect(self, effect: DropEffect) -> Self
pub fn with_mode(self, mode: DragMode) -> Self
pub fn with_pointer_kind(self, pointer_kind: PointerKind) -> Self
pub fn with_source_rect(self, source_rect: Option<Rect>) -> Self