pub struct ZoneLocation {
pub window: WindowKey,
pub zone: ZoneId,
}Expand description
A drop-zone identity qualified by the joined window that owns it.
Legacy single-window APIs continue to expose ZoneId; worlds use this
richer identity so separate windows may safely reuse the same explicit id.
Fields
window: WindowKeyzone: ZoneIdTrait Implementations
Sourceimpl Clone for ZoneLocation
impl Clone for ZoneLocation
Sourcefn clone(&self) -> ZoneLocation
fn clone(&self) -> ZoneLocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ZoneLocation
Sourceimpl Debug for ZoneLocation
impl Debug for ZoneLocation
impl Eq for ZoneLocation
Sourceimpl Hash for ZoneLocation
impl Hash for ZoneLocation
Sourceimpl Ord for ZoneLocation
impl Ord for ZoneLocation
Sourcefn cmp(&self, other: &ZoneLocation) -> Ordering
fn cmp(&self, other: &ZoneLocation) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for ZoneLocation
impl PartialEq for ZoneLocation
Sourceimpl PartialOrd for ZoneLocation
impl PartialOrd for ZoneLocation
impl StructuralPartialEq for ZoneLocation