pub struct FileDrop {
pub files: Vec<FileData>,
pub client: Point,
pub element: Point,
}Expand description
A batch of dropped or selected files plus its interaction coordinates.
Fields
files: Vec<FileData>client: PointPointer position in client (viewport) coordinates.
File-picker selections have no drop position, so this is (0, 0).
element: PointPointer position relative to the drop zone element.
File-picker selections have no drop position, so this is (0, 0).