#[non_exhaustive]pub struct SortEvent {
pub from: usize,
pub to: usize,
}Expand description
“Move the item at from so it ends up at index to.”
Non-exhaustive so reorder context can be added without a major release;
synthesize your own (reorder buttons, tests) via SortEvent::new.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.from: usizeto: usizeImplementations