pub fn rerender(dom: &mut VirtualDom)Expand description
Flush pending reactivity so the tree reflects the simulated state -
call between driver actions and markup assertions
(dioxus_ssr::render).
pub fn rerender(dom: &mut VirtualDom)Flush pending reactivity so the tree reflects the simulated state -
call between driver actions and markup assertions
(dioxus_ssr::render).